%% parameters setting
% System Redundancy (SR)
lambdaB_SR = 11.76e-6;% hours^(-1)
lambdaR_SR = 16.6e-6;
muB_SR = 0.5;% hours^(-1)
muR_SR = muB_SR;

% Component Redundancy (CR)
lambdaB_CR = 17*lambdaB_SR;
lambdaR_CR = 17*lambdaR_SR;
muB_CR = 0.5;% hours^(-1)
muR_CR = muR_SR;

ModulePower = 10;% kW
minLoad = 40;% kW
loadStep = 20;% kW

%% start evaluation
numberOfEvaluations = 6;

MTTF_perc_impr = zeros(numberOfEvaluations,1);
MTBF_perc_impr = zeros(numberOfEvaluations,1);
MTBF_SR = zeros(numberOfEvaluations,1);
MTBF_CR = zeros(numberOfEvaluations,1);
Energy_perc_impr = zeros(numberOfEvaluations,1);
for i = 1 : numberOfEvaluations
    Load = minLoad + i*loadStep;% kW

    n = ceil(Load/ModulePower);
    nm = n + 3;

    PotTransformerMonolite=0.04*2*Load;
    PotTransformerModular=0.04*Load;

    Energy_perc_impr(i) = 100; % estimate only considering transformers

    [A_SR,MTTF_SR,MTBF_SR_value] = evaluate_SR(nm,n,lambdaB_SR,lambdaR_SR,muB_SR,muR_SR);
    [A_CR,MTTF_CR,MTBF_CR_value] = evaluate_CR(nm,n,lambdaB_CR,lambdaR_CR,muB_CR,muR_CR);
    
    MTBF_SR(i) = MTBF_SR_value;
    MTBF_CR(i) = MTBF_CR_value;

    A_perc_impr = 100*(A_CR-A_SR)/A_SR;
    MTTF_perc_impr(i) = 100*(MTTF_CR-MTTF_SR)/MTTF_SR;
    MTBF_perc_impr(i) = 100*(MTBF_CR_value-MTBF_SR_value)/MTBF_SR_value;

end

%% Plot
x =  minLoad : loadStep : (minLoad+(numberOfEvaluations-1)*loadStep);

zeroline=zeros(1,length(x));

fs = 14;
f1=figure(1);
f1.Position = [50 50 650 650];
title('Percentage of improvement','FontSize',fs-2);
hold on;
xlabel('DC load [kW]','FontWeight','bold','FontSize',fs);
plot(x,MTBF_perc_impr,'Color',[0,0,0],'LineWidth',2);
plot(x,zeroline,'Color',[0.4,0.4,0.4]);

f2=figure(2);
f2.Position = [50 50 650 650];
title('Mean Time Between two Failures (MTBF)','FontSize',fs);
hold on;
xlabel('DC load [kW]','FontWeight','bold','FontSize',fs);
ylabel('MTBF [hours]','FontWeight','bold','FontSize',fs);
plot(x,MTBF_SR,"--",'Color',[0.5,0,0.5],'LineWidth',2);
plot(x,MTBF_CR,"-.",'Color',[0,0.7,0],'LineWidth',2);
legend('SR','CR','FontSize',fs);